@@ -107,7 +107,7 @@ class HTTPClient(object):
         if 'body' in kwargs:
             curl.append('-d \'%s\'' % kwargs['body'])
 
-        curl.append('%s%s' % (self.endpoint, url))
+        curl.append('%s/%s' % (self.endpoint.rstrip('/'), url.lstrip('/')))
         LOG.debug(' '.join(curl))
 
     @staticmethod
@@ -170,7 +170,7 @@ class HTTPClient(object):
 
         if 400 <= resp.status < 600:
             LOG.warn("Request returned failure status.")
-            raise exc.from_response(resp)
+            raise exc.from_response(resp, ''.join(body_iter))
         elif resp.status in (301, 302, 305):
             # Redirected. Reissue the request to the new location.
             return self._http_request(resp['location'], method, **kwargs)
